@@ -7,7 +7,7 @@ from .base import BaseTable, engine, meta
 class KlineData(BaseTable):
     def __init__(self, table_name="kline_data_1min", source=None, *args, **kwargs):
         if source is not None:
-            table_name = f"{source}_{table_name}"
+            table_name = f"{source.lower()}_{table_name}"
 
         super(KlineData, self).__init__(table_name=table_name, *args, **kwargs)
         self.table = Table(self.table_name, meta,
@@ -18,13 +18,13 @@ class KlineData(BaseTable):
                            Column('low', Float, comment='low', default=0),
                            Column('high', Float, comment='high', default=0),
                            Column('vol', Float, comment='vol', default=0),
-                           extend_existing=True,
-                           autoload=True,
+                           # extend_existing=True,
+                           # autoload=True
                            )
-        meta.create_all(engine)
+        self.create()
 
     def select_symbol_maxmin(self, symbol):
-        meta.create_all(engine)
+        self.create()
         s = select(self.table.columns.symbol,
                    func.max(self.table.columns.timestamp).label('max_time'),
                    func.min(self.table.columns.timestamp).label('min_time')
