@@ -22,13 +22,14 @@ def load_month(exchange: Exchange, tmp_path, timeframe='1m'):
         filename = f"{exchange.name}-kline-{datetime(today.year, today.month - month_index, 1).strftime('%Y-%m')}"
         path_csv = f"{tmp_path}/kline/{filename}.csv"
         path_tar = f"{tmp_path}/kline/{filename}.tar.xz"
+        print(path_tar)
         if os.path.exists(path_tar):
             continue
 
         # 下载
         exchan.load_all(timeframe=timeframe)
         # 保存
-        exchan.table.to_csv(path_tar)
+        exchan.table.to_csv_all(path_csv)
         # 压缩
         with tarfile.open(path_tar, "w:xz") as tar:
             tar.add(path_csv)
